---
title: "BGP Communities"
geekdocDescription: "BGP communities used in the network"
weight: 50
---
This page describes the use of BGP communities within the network.

## DN42 Communities

[DN42 Communities](https://dn42.net/howto/Bird-communities) are applied both internally and externally, and are used to influence the [Routing Policy](/home/routing-policy).

|Community &nbsp;|Description|
|:---|:---|
|( 64511 : 0 < x < 21 )   &nbsp; | Max latency |
|( 64511 : 20 < x < 30 ) &nbsp; | Min bandwidth |
|( 64511 : 30 < x < 35 ) &nbsp; | Min encryption |
|( 64511 : 40 < x < 54 ) &nbsp; | Route Origin |

## Well Known BGP Communities

The following well known communities are implemented.

|Community &nbsp;|Description|Action|
|:---|:---|:---|
| ( 65535 : 65281 ) &nbsp; | No Export                  | Prefix should not be exported outside of AS4242422601 | 
| ( 65535 : 65282 ) &nbsp; | No Advertise &nbsp; | Prefix should not be exported to any peers |
| ( 65535 : 65283 ) &nbsp; | Local-AS                   | Prefix should not be exported outside of region |

## burble.dn42 Specific Communities

burble.dn42 implements [large BGP communities](http://largebgpcommunities.net/), with [ISO 3166-1 / UNSD](https://en.wikipedia.org/wiki/ISO_3166-1) country, and [UNSD](https://unstats.un.org/unsd/methodology/m49/) region codes. 

### Informational Communities

|Community &nbsp;|Description|
|:---|:---|
| ( 4242422601 : 120 : _host code_ )   &nbsp; | Route learned on this host | 
| ( 4242422601 : 130 : 1 )   &nbsp; | Route is a direct peer | 
| ( 4242422601 : 140 : _DN42 region_ )   &nbsp; | Route learned in this DN42 region | 
  
### Internal Ghost Route Protection

In a large network like burble.dn42 it can take some time for route updates
to be distributed and for the network to settle following changes. As changes
ripple through the network it can create a cascade of ghost updates, each with
an increasing internal path length, or adjusted latency metric. Worse the
cascade of updates can also be re-distributed to peers, creating a significant
multiplier for the number of updates from a single change. 

To protect against ghost routes, a community is used to track how many internal
hops a route has. In a fully meshed network like burble.dn42, a genuine route should
never have more than two internal hops, so an export filter is used to prevent
distribution of longer paths. 

|Community &nbsp;|Description|
|:---|:---|
| ( 4242422601 : 100 : 1 )   &nbsp; | Added on first internal re-distribution |
| ( 4242422601 : 100 : 2 )   &nbsp; | Added on second re-distribution and prevents further re-distribution within burble.dn42 |

The ( 4242422601 : 100 : x ) communities are not exported to peers.




